If you want to create a folder to be shared by CIFS clients, do one of the following:
Note: By default, three shares are created during CIFS setup: C$, IPC$, and HOME. In filer console displays, the C$ share corresponds in UNIX to /vol/vol0 and the HOME share corresponds to /vol/vol0/home.
To create a share from the Windows NT desktop using Server Manager, create a folder, then share it by following these steps.
To change the description and user limit with Server Manager, follow these steps.
Following is the syntax for the cifs shares command for creating a share:
cifs shares -add sharename path [ -comment description ] [ -forcegroup groupname ] [ -maxusers n ]
The following table describes the parameters.
| Variable | Description |
|---|---|
| description | A string describing the purpose of the share. It must contain only characters in the current code page. It is required by the CIFS protocol and is displayed in the share list in Network Neighborhood on the client. If the description contains spaces, you must enclose it in single quotation marks. |
| groupname | The name of the group you want all files in the share to get the group membership of. |
| n | The maximum number of users that you specify can connect to the share at the same time. The limit on this number is dependent on filer memory, and is shown in "Limits on CIFS open files, sessions, and shares." |
| path |
The path name, relative to the root of the filer's file system, of the root directory of the share.
Note: Because the cifs shares command is case-sensitive, be sure that you use the appropriate case when entering the path name. Separators used in the path name must be forward slashes (/). |
| sharename |
The name of the share, which is used by CIFS users to obtain access to the directory on the filer.
If sharename already exists, the cifs shares -add command fails.
Caution: Do not create shares whose names end with a dollar sign ($); doing so might cause conflicts with reserved names. In particular, do not create shares called C$ or ADMIN$. C$ is a reserved share name and ADMIN$ is an illegal share name. |
The following example creates a new share called library:
cifs shares -add library /vol/vol0/home/lib 'New file library'
This example creates the library share and defines it as HOME\LIB (/home/lib in UNIX notation) in the filer's root volume. With the appropriate access rights, CIFS users can gain access to the HOME\LIB directory in the root volume, which is displayed as the library share on their computers. For more information about setting access rights, refer to "Assigning and changing access rights."
To change the description, forced file ownership, and user limits of a share, use the following command:
cifs shares -change sharename [ -comment description | -nocomment ] [ -forcegroup groupname | -noforcegroup ]
[ -maxusers n | -nomaxusers ]
The following table describes the parameters.
| Parameter or variable | Description |
|---|---|
| description | A string describing the purpose of the share. It must contain only characters in the current code page. It is displayed in the share list in Network Neighborhood on the client. If the description contains spaces, you must enclose it in single quotation marks. |
| groupname | The name of the group you want all files in the share to get the group membership of. |
| n | The maximum number of users that you specify can connect to the share at the same time. The limit on this number is dependent on filer memory, and is shown in "Limits on CIFS open files, sessions, and shares." |
| -nocomment | Specifies no description. |
| -noforcegroup | Specifies no particular group to own the files that are created in the share. |
| -nomaxusers | Specifies no maximum number of users that can connect to the share at the same time. |
| sharename | The name of the share, which is used by CIFS users to obtain access to the directory on the filer. It must contain only characters in the current code page. |
Copyright © 1999, Network Appliance, Inc. All rights reserved.
Part No. 210-02334
File: cifs9.htm
Last updated: 04/26/99 08:11:33